:tocdepth: 1

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _releasenotes:

Grappelli 4.0.x Release Notes
=============================

**Grappelli 4.0.x is compatible with Django 5.0**.

Update from Grappelli 3.x
-------------------------

* Update Django to 5.x and check the Django release notes
* Update Grappelli to 4.x
